/*
 * Decompiled with CFR 0.152.
 */
package com.hst.taxService.service;

import com.hst.common.domain.BaseAppServiceDomain;
import com.hst.common.domain.TaxCommonAppServiceDomain;
import com.hst.common.domain.TaxCommonReturnDomain;
import com.hst.common.service.BaseBusinessService;

public interface TaxWxCommonAppService
extends BaseBusinessService {
    public TaxCommonReturnDomain queryZxrdGetList(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryZxrdGetMess(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain zxrdPutViewTime(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryWsxtGetList(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryWsxtGetMess(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain WsxtPutDownLog(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryWsxtGetJsnr(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryBsznGetSxfl(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryBsznGetSssxList(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryBsznGetSssxSm(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryBswdGetBsdtList(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryBswdGetBsdtMess(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryBswdGetBsdtLsDhxx(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryBswdGetShhwdList(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryBswdGetShhwdMess(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain querySjqhGetBsdtList(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain querySjqhGetDryqhxx(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain querySjqhGetDhrs(BaseAppServiceDomain var1, TaxCommonAppServiceDomain var2) throws Exception;

    public TaxCommonReturnDomain querySjqhGetJhxtYwfl(BaseAppServiceDomain var1, TaxCommonAppServiceDomain var2) throws Exception;

    public TaxCommonReturnDomain querySjqhGetSjqhhm(BaseAppServiceDomain var1, TaxCommonAppServiceDomain var2) throws Exception;

    public TaxCommonReturnDomain querySjqhZfSjqh(BaseAppServiceDomain var1, TaxCommonAppServiceDomain var2) throws Exception;

    public TaxCommonReturnDomain querySjcxGetNsrxx(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain querySjcxGetSbqx(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryFpcy(BaseAppServiceDomain var1, TaxCommonAppServiceDomain var2) throws Exception;

    public TaxCommonReturnDomain queryYybsYysj(BaseAppServiceDomain var1, TaxCommonAppServiceDomain var2) throws Exception;

    public TaxCommonReturnDomain queryYybsYyqh(BaseAppServiceDomain var1, TaxCommonAppServiceDomain var2) throws Exception;

    public TaxCommonReturnDomain queryYybsSfyz(BaseAppServiceDomain var1, TaxCommonAppServiceDomain var2) throws Exception;

    public TaxCommonReturnDomain queryYybsGetYyqhhm2(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain doQxyyqhhm(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain doGxBsdtJhyxgz(BaseAppServiceDomain var1, TaxCommonAppServiceDomain var2) throws Exception;

    public TaxCommonReturnDomain doGxBsdtYhfl(BaseAppServiceDomain var1, TaxCommonAppServiceDomain var2) throws Exception;

    public TaxCommonReturnDomain doYgzPxdj(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryYybsGetYysj2(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryYybsGetYyGzr(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryYybsGetJhxtYwfl2(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain saveYgzZxd(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryYgzZxd(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain queryYybsGetJhxtYwflYy(BaseAppServiceDomain var1, TaxCommonAppServiceDomain var2) throws Exception;

    public TaxCommonReturnDomain yyqhGetBsdtList(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain yybsGetYyyxx(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain gzhTzggList(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain gzhTzggNr(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain gzhSytzggList(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain SjqhGetDryqhxxAll(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain YybsGetYyyxxAll(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain yybsFsdxyzm(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain yybsDxyzmxy(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain yybsCxlsyyqhxx(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain YybsDayYyqhtj(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain SjqhGetDayQhtj(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain SjqhPutqhxx(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain SjqhGetPhxx(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain SjqhGetJhList(BaseAppServiceDomain var1) throws Exception;

    public TaxCommonReturnDomain SjqhPj(BaseAppServiceDomain var1) throws Exception;
}
